{% extends "onto/crud/base.html" %}

{% block main %}


{% if object %}
<a href="../">Back to list</a>
<h1>Edit {{ object }}</h1>
{% else %}
<a href="./">Back to list</a>
<h1>Create new {{ model_meta.verbose_name | title }}</h1>
{% endif %}

<form method="post">
    {% csrf_token %}
    {{ form }}
    <input type="submit" value="Save">
</form>
{% endblock %}