{% extends "onto/crud/base.html" %}

{% block main %}

<a href="edit">Create new {{ model_meta.verbose_name | title }}</a>

<h1>{{ model_meta.verbose_name_plural | title }}</h1>
<ul>
{% for object in objects %}
  <li><a href="edit/{{object.pk}}">{{ object }}</a></li>
{% endfor %}
</ul>
{% endblock %}