<div class="modal" hx-boost="true" hx-target="this" hx-swap="afterend" hx-push-url="false">
    <button class="exit" _="on click remove closest .modal">✕</button>
    {% block main %}
    {% endblock %}
</div>