<!DOCTYPE html>
<html lang=en>
{% load static %}
<head>
<meta charset=utf-8>
<title>{% block title %}Onto Admin{% endblock %}</title>

<link href='https://fonts.googleapis.com/css?family=Source+Sans+Pro' rel='stylesheet' type='text/css'>

<link rel="stylesheet" href="{% static 'onto/crud/base.css' %}"/>

<script src="{% static 'onto/crud/vendor/htmx.min.js' %}"></script>
<script src="{% static 'onto/crud/vendor/_hyperscript.min.js' %}"></script>
{% block head %}{% endblock %}
</head>
<body hx-headers='{"X-CSRFToken": "{{ csrf_token }}"}'>
{% block body %}
    <header>
        {% block header %}{% endblock %}
    </header>
    <nav>
        {% block nav %}{% endblock %}
    </nav>
    <main id="main-content">
        {% block main %}This page is blank.{% endblock %}
    </main>
    <footer>
        {% block footer %}{% endblock %}
    </footer>
{% endblock %}
</body>